==> autoprofile_2.10.orig.tar.gz: autoprofile-2.10/src/comp_textfile.c <==
/*--------------------------------------------------------------------------*
 * AUTOPROFILE                                                              *
 *                                                                          *
 * A Gaim away message and profile manager that supports dynamic text       *
 *                                                                          *
 * AutoProfile is the legal property of its developers.  Please refer to    *
 * the COPYRIGHT file distributed with this source distribution.            *
 *                                                                          *
 * This program is free software; you can redistribute it and/or modify     *
 * it under the terms of the GNU General Public License as published by     *
 * the Free Software Foundation; either version 2 of the License, or        *
 * (at your option) any later version.                                      *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA *
 *--------------------------------------------------------------------------*/

#include "component.h"

/*---------- TEXT FILE: Text from a file ----------*/
GtkWidget *file_entry;

/* Read file into string and return */
char *text_file_generate ()
{
  char *text, *text_start;
  char current;

  int max = gaim_prefs_get_int (
    "/plugins/gtk/autoprofile/components/text_size");
  FILE *fp = fopen (
    gaim_prefs_get_string ("/plugins/gtk/autoprofile/components/text_file"),
    "r");

  /* Bad file check */
  if (fp == NULL) {
    return NULL;
  }

  text = (char *)malloc (max + 1);
  text_start = text;

  /* Read the file */
  while (max-- !=0 && (current = getc(fp)) != EOF) {
    *text++ = current;
  }

  *text = '\0';
  if (text - text_start > 0 && *(text - 1) == '\n')
    *(text - 1) = '\0';

  fclose (fp);
  
  return text_start;
}

static gboolean text_file_update (GtkWidget *widget, GdkEventFocus *evt, 
                                gpointer data)
{
	gaim_prefs_set_string (
    "/plugins/gtk/autoprofile/components/text_file",
    gtk_entry_get_text (GTK_ENTRY (file_entry)));
  return FALSE;
}

static gboolean text_file_update_size (GtkWidget *widget, GdkEventFocus *evt, 
                                      gpointer data)
{
  gaim_prefs_set_int ("/plugins/gtk/autoprofile/components/text_size",
    gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (widget)));
  return FALSE;
}

void text_file_filename (GtkWidget *widget, gpointer user_data) {
  GtkWidget *file_selector = (GtkWidget *)user_data;
  const gchar *selected_filename;

  selected_filename = gtk_file_selection_get_filename (
    GTK_FILE_SELECTION (file_selector));

  gaim_prefs_set_string ("/plugins/gtk/autoprofile/components/text_file",
    selected_filename);
  gtk_entry_set_text (GTK_ENTRY (file_entry), gaim_prefs_get_string (
    "/plugins/gtk/autoprofile/components/text_file"));
}

/* Creates and pops up file selection dialog for fortune file */
void text_file_selection (GtkWidget *widget, gpointer user_data) {
  GtkWidget *file_selector;
  const char *cur_file;
  
  /* Create the selector */
  file_selector = gtk_file_selection_new (
    "Select a text file with content");

  cur_file = gaim_prefs_get_string (
    "/plugins/gtk/autoprofile/components/text_file");
  if (strlen (cur_file) > 1) {
    gtk_file_selection_set_filename (
      GTK_FILE_SELECTION (file_selector), cur_file); 
  }
  
  g_signal_connect (GTK_OBJECT(
                      GTK_FILE_SELECTION(file_selector)->ok_button),
                    "clicked", G_CALLBACK (text_file_filename),
                    (gpointer) file_selector);
   			   
  /* Destroy dialog box when the user clicks button. */
  g_signal_connect_swapped (GTK_OBJECT(
      GTK_FILE_SELECTION(file_selector)->ok_button), 
    "clicked", G_CALLBACK (gtk_widget_destroy), (gpointer) file_selector); 

  g_signal_connect_swapped (GTK_OBJECT (
      GTK_FILE_SELECTION (file_selector)->cancel_button), 
    "clicked", G_CALLBACK (gtk_widget_destroy), (gpointer) file_selector); 
   
  /* Display dialog */
  gtk_widget_show (file_selector);
}

/* Pop up message with instructions */
void text_file_info_button (GtkButton *button, gpointer data) 
{
  if (!strcmp ((char *) data, "itunes")) {
    gaim_notify_formatted (NULL, _("iTunes"), _("Current song in iTunes"), NULL,
      _("Get TuneCam from <a href=\""
        "http://www.soft-o-mat.com/productions.shtml\">"
        "http://www.soft-o-mat.com/productions.shtml</a> and start it.<br>"
        "Create a html file that contains the following text:<br><br>&lt;tc"
        "&gt;artist&lt;/tc&gt; - &lt;tc&gt;title&lt;/tc&gt;<br><br>and "
        "press the \"T\" button.  Import the html file as a template for "
        "the \"File Track\" and whatever else you see fit.  Then select "
        "the \"G\" button and choose the location of the output file which "
        "will be used in this component"), 
      NULL, NULL);  
  } else if (!strcmp ((char *) data, "xmms")) {
    gaim_notify_formatted (NULL, _("XMMS"), _("Current song in XMMS"), NULL,
     _("Included in the misc folder of AutoProfile is a script called \""
       "xmms_currenttrack\".  Install this script in your $PATH and give it "
       "executable permissions, and specify the program using a pipe.<br><br>"
       "Alternatively, in XMMS, go to Options->Preferences->Effects/General "
       "Plugins.<br>Configure the \"Song Change\" plugin.  In the song change"
       " command box, put<br><br>echo \"%s\" > /path/to/output/file<br><br>"
       "and be sure to enable the plugin.  Select the file location in "
       "AutoProfile and you should be done"),
      NULL, NULL);
  } else if (!strcmp ((char *) data, "wmp")) {
    gaim_notify_formatted (NULL, _("Windows Media Player"), 
      _("Current song in Windows Media Player"), NULL,
      _("Download NowPlaying, a plugin for WMP from <a href=\""
        "http://www.wmplugins.com/ItemDetail.aspx?ItemID=357\">"
        "http://www.wmplugins.com/ItemDetail.aspx?ItemID=357</a> and follow "
        "the included installation instructions.<br>Set the output filename "
        "to the file you choose in this component"),
        NULL, NULL);
  } else if (!strcmp ((char *) data, "winamp")) {
    gaim_notify_formatted (NULL, _("Winamp"), _("Current song in Winamp"), NULL,
      _("Get TitleSpy from <a href=\""
        "http://www.winamp.com/plugins/details.php?id=10248\">"
        "http://www.winamp.com/plugins/details.php?id=10248</a> and install/"
        "enable it.<br>Set the output filename to the file you choose in this "
        "component and be sure to set \"on xx\" characters to a non-zero "
        "value (maximum number of letters to display from the title)"),
        NULL, NULL);
  } else if (!strcmp ((char *) data, "foobar")) {
    gaim_notify_formatted (NULL, _("Foobar 2000"),
      _("Current song in Foobar 2000"), NULL,
      _("Go to <a href=\"http://pelit.koillismaa.fi/plugins/general.php#29\">"
        "http://pelit.koillismaa.fi/plugins/general.php#29</a> and download "
        "the text writer plugin and stick it in the foobar2000\\components\\ "
        "folder. Go to preferences and make sure it's enabled. Go ahead and "
        "customize it. Lastly, be sure to select the outputted file in this "
        "component.  That's it!"),
        NULL, NULL);
  }
}

/* Create the menu */
GtkWidget *text_file_menu ()
{
  GtkWidget *ret = gtk_vbox_new (FALSE, 5);
  GtkWidget *hbox, *label, *button, *spinner;

  label = gtk_label_new (_("Select text file with source content"));
  gtk_box_pack_start (GTK_BOX (ret), label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label), 0, 0);

  hbox = gtk_hbox_new (FALSE, 5);
  gtk_box_pack_start (GTK_BOX (ret), hbox, FALSE, FALSE, 0);
  /* Text entry to type in file name */
  file_entry = gtk_entry_new ();
  gtk_box_pack_start (GTK_BOX (hbox), file_entry, FALSE, FALSE, 0);
  gtk_entry_set_text (GTK_ENTRY (file_entry), gaim_prefs_get_string (
    "/plugins/gtk/autoprofile/components/text_file"));
  g_signal_connect (G_OBJECT (file_entry), "focus-out-event",
                    G_CALLBACK (text_file_update), NULL);
  /* Button to bring up file select dialog */
  button = gtk_button_new_with_label ("Browse ...");
  g_signal_connect (G_OBJECT (button), "clicked",
                    G_CALLBACK (text_file_selection), NULL);

  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);

  hbox = gtk_hbox_new (FALSE, 5);
  gtk_box_pack_start (GTK_BOX (ret), hbox, FALSE, FALSE, 0);
  label = gtk_label_new (_("Max characters to read from file: "));
  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
  spinner = gtk_spin_button_new_with_range (1, 1000, 1);
  gtk_box_pack_start (GTK_BOX (hbox), spinner, FALSE, FALSE, 0);
  gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinner), gaim_prefs_get_int (
    "/plugins/gtk/autoprofile/components/text_size"));
  g_signal_connect (G_OBJECT (spinner), "value-changed",
                    G_CALLBACK (text_file_update_size), NULL);

  label = gtk_label_new (_("Play the current song in:"));
  gtk_box_pack_start (GTK_BOX (ret),
    gtk_hseparator_new (), 0, 0, 0);

  gtk_box_pack_start (GTK_BOX (ret), label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label), 0, 0);

  hbox = gtk_hbox_new (FALSE, 5);
  gtk_box_pack_start (GTK_BOX (ret), hbox, FALSE, FALSE, 0);
  
  button = gtk_button_new_with_label ("Winamp");
  g_signal_connect (G_OBJECT (button), "clicked",
    G_CALLBACK (text_file_info_button), "winamp");
  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0); 

  button = gtk_button_new_with_label ("XMMS");
  g_signal_connect (G_OBJECT (button), "clicked",
    G_CALLBACK (text_file_info_button), "xmms");
  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0); 
    
  button = gtk_button_new_with_label ("Windows Media Player");
  g_signal_connect (G_OBJECT (button), "clicked",
    G_CALLBACK (text_file_info_button), "wmp");
  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0); 
    
  button = gtk_button_new_with_label ("iTunes");
  g_signal_connect (G_OBJECT (button), "clicked",
    G_CALLBACK (text_file_info_button), "itunes");
  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0); 

  button = gtk_button_new_with_label ("Foobar");
  g_signal_connect (G_OBJECT (button), "clicked",
    G_CALLBACK (text_file_info_button), "foobar");
  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);

  return ret;
}

void text_file_init () {
  gaim_prefs_add_string ("/plugins/gtk/autoprofile/components/text_file","");
  gaim_prefs_add_int ("/plugins/gtk/autoprofile/components/text_size", 
    1000);
}

struct component text =
{
  N_("Text File / Songs"),
  N_("Copies text from file- external programs (e.g. XMMS, Winamp, iTunes)\n"
     "can modify on regular basis"),
  'x',
  &text_file_generate,
  &text_file_init,
  NULL,
  NULL,
  &text_file_menu
};

==> autoprofile_2.14.orig.tar.gz: autoprofile-2.14/src/comp_textfile.c <==
/*--------------------------------------------------------------------------*
 * AUTOPROFILE                                                              *
 *                                                                          *
 * A Gaim away message and profile manager that supports dynamic text       *
 *                                                                          *
 * AutoProfile is the legal property of its developers.  Please refer to    *
 * the COPYRIGHT file distributed with this source distribution.            *
 *                                                                          *
 * This program is free software; you can redistribute it and/or modify     *
 * it under the terms of the GNU General Public License as published by     *
 * the Free Software Foundation; either version 2 of the License, or        *
 * (at your option) any later version.                                      *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA *
 *--------------------------------------------------------------------------*/

#include "component.h"

/*---------- TEXT FILE: Text from a file ----------*/
GtkWidget *file_entry;

/* Read file into string and return */
char *text_file_generate ()
{
  char *text, *text_start;
  char current;

  int max = gaim_prefs_get_int (
    "/plugins/gtk/autoprofile/components/text_size");
  FILE *fp = fopen (
    gaim_prefs_get_string ("/plugins/gtk/autoprofile/components/text_file"),
    "r");

  /* Bad file check */
  if (fp == NULL) {
    return NULL;
  }

  text = (char *)malloc (max + 1);
  text_start = text;

  /* Read the file */
  while (max-- !=0 && (current = getc(fp)) != EOF) {
    *text++ = current;
  }

  *text = '\0';
  if (text - text_start > 0 && *(text - 1) == '\n')
    *(text - 1) = '\0';

  fclose (fp);
  
  return text_start;
}

static gboolean text_file_update (GtkWidget *widget, GdkEventFocus *evt, 
                                gpointer data)
{
	gaim_prefs_set_string (
    "/plugins/gtk/autoprofile/components/text_file",
    gtk_entry_get_text (GTK_ENTRY (file_entry)));
  return FALSE;
}

static gboolean text_file_update_size (GtkWidget *widget, GdkEventFocus *evt, 
                                      gpointer data)
{
  gaim_prefs_set_int ("/plugins/gtk/autoprofile/components/text_size",
    gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (widget)));
  return FALSE;
}

void text_file_filename (GtkWidget *widget, gpointer user_data) {
  GtkWidget *file_selector = (GtkWidget *)user_data;
  const gchar *selected_filename;

  selected_filename = gtk_file_selection_get_filename (
    GTK_FILE_SELECTION (file_selector));

  gaim_prefs_set_string ("/plugins/gtk/autoprofile/components/text_file",
    selected_filename);
  gtk_entry_set_text (GTK_ENTRY (file_entry), gaim_prefs_get_string (
    "/plugins/gtk/autoprofile/components/text_file"));
}

/* Creates and pops up file selection dialog for fortune file */
void text_file_selection (GtkWidget *widget, gpointer user_data) {
  GtkWidget *file_selector;
  const char *cur_file;
  
  /* Create the selector */
  file_selector = gtk_file_selection_new (
    "Select a text file with content");

  cur_file = gaim_prefs_get_string (
    "/plugins/gtk/autoprofile/components/text_file");
  if (strlen (cur_file) > 1) {
    gtk_file_selection_set_filename (
      GTK_FILE_SELECTION (file_selector), cur_file); 
  }
  
  g_signal_connect (GTK_OBJECT(
                      GTK_FILE_SELECTION(file_selector)->ok_button),
                    "clicked", G_CALLBACK (text_file_filename),
                    (gpointer) file_selector);
   			   
  /* Destroy dialog box when the user clicks button. */
  g_signal_connect_swapped (GTK_OBJECT(
      GTK_FILE_SELECTION(file_selector)->ok_button), 
    "clicked", G_CALLBACK (gtk_widget_destroy), (gpointer) file_selector); 

  g_signal_connect_swapped (GTK_OBJECT (
      GTK_FILE_SELECTION (file_selector)->cancel_button), 
    "clicked", G_CALLBACK (gtk_widget_destroy), (gpointer) file_selector); 
   
  /* Display dialog */
  gtk_widget_show (file_selector);
}

/* Pop up message with instructions */
void text_file_info_button (GtkButton *button, gpointer data) 
{
  if (!strcmp ((char *) data, "itunes")) {
    gaim_notify_formatted (NULL, _("iTunes"), _("Current song in iTunes"), NULL,
      _("Get TuneCam from <a href=\""
        "http://www.soft-o-mat.com/productions.shtml\">"
        "http://www.soft-o-mat.com/productions.shtml</a> and start it.<br>"
        "Create a html file that contains the following text:<br><br>&lt;tc"
        "&gt;artist&lt;/tc&gt; - &lt;tc&gt;title&lt;/tc&gt;<br><br>and "
        "press the \"T\" button.  Import the html file as a template for "
        "the \"File Track\" and whatever else you see fit.  Then select "
        "the \"G\" button and choose the location of the output file which "
        "will be used in this component"), 
      NULL, NULL);  
  } else if (!strcmp ((char *) data, "xmms")) {
    gaim_notify_formatted (NULL, _("XMMS"), _("Current song in XMMS"), NULL,
     _("Included in the misc folder of AutoProfile is a script called \""
       "xmms_currenttrack\".  Install this script in your $PATH and give it "
       "executable permissions, and specify the program using a pipe.<br><br>"
       "Alternatively, in XMMS, go to Options->Preferences->Effects/General "
       "Plugins.<br>Configure the \"Song Change\" plugin.  In the song change"
       " command box, put<br><br>echo \"%s\" > /path/to/output/file<br><br>"
       "and be sure to enable the plugin.  Select the file location in "
       "AutoProfile and you should be done"),
      NULL, NULL);
  } else if (!strcmp ((char *) data, "wmp")) {
    gaim_notify_formatted (NULL, _("Windows Media Player"), 
      _("Current song in Windows Media Player"), NULL,
      _("Download NowPlaying, a plugin for WMP from <a href=\""
        "http://www.wmplugins.com/ItemDetail.aspx?ItemID=357\">"
        "http://www.wmplugins.com/ItemDetail.aspx?ItemID=357</a> and follow "
        "the included installation instructions.<br>Set the output filename "
        "to the file you choose in this component"),
        NULL, NULL);
  } else if (!strcmp ((char *) data, "amip")) {
    gaim_notify_formatted (NULL, _("iTunes/Winamp/Foobar/Apollo/QCD"),
      _("Current song in iTunes/Winamp/Foobar/Apollo/QCD"), NULL,
      _("Get the version of AMIP associated with your player from <a href=\""
        "http://amip.tools-for.net/\">"
        "http://amip.tools-for.net/</a> and install/"
        "enable it.<br>"
        "Check the box \"Write song info to file\", play with the settings, "
        "and set the file in this component to be the file in the AMIP "
        "options."),
      NULL, NULL);
  }
}

/* Create the menu */
GtkWidget *text_file_menu ()
{
  GtkWidget *ret = gtk_vbox_new (FALSE, 5);
  GtkWidget *hbox, *label, *button, *spinner;

  label = gtk_label_new (_("Select text file with source content"));
  gtk_box_pack_start (GTK_BOX (ret), label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label), 0, 0);

  hbox = gtk_hbox_new (FALSE, 5);
  gtk_box_pack_start (GTK_BOX (ret), hbox, FALSE, FALSE, 0);
  /* Text entry to type in file name */
  file_entry = gtk_entry_new ();
  gtk_box_pack_start (GTK_BOX (hbox), file_entry, FALSE, FALSE, 0);
  gtk_entry_set_text (GTK_ENTRY (file_entry), gaim_prefs_get_string (
    "/plugins/gtk/autoprofile/components/text_file"));
  g_signal_connect (G_OBJECT (file_entry), "focus-out-event",
                    G_CALLBACK (text_file_update), NULL);
  /* Button to bring up file select dialog */
  button = gtk_button_new_with_label ("Browse ...");
  g_signal_connect (G_OBJECT (button), "clicked",
                    G_CALLBACK (text_file_selection), NULL);

  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);

  hbox = gtk_hbox_new (FALSE, 5);
  gtk_box_pack_start (GTK_BOX (ret), hbox, FALSE, FALSE, 0);
  label = gtk_label_new (_("Max characters to read from file: "));
  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
  spinner = gtk_spin_button_new_with_range (1, AP_SIZE_MAXIMUM - 1, 1);
  gtk_box_pack_start (GTK_BOX (hbox), spinner, FALSE, FALSE, 0);
  gtk_spin_button_set_value (GTK_SPIN_BUTTON (spinner), gaim_prefs_get_int (
    "/plugins/gtk/autoprofile/components/text_size"));
  g_signal_connect (G_OBJECT (spinner), "value-changed",
                    G_CALLBACK (text_file_update_size), NULL);

  gtk_box_pack_start (GTK_BOX (ret),
    gtk_hseparator_new (), 0, 0, 0);

  /* Windows */
  label = gtk_label_new (_("Windows users: Play the current song in:"));
  gtk_box_pack_start (GTK_BOX (ret), label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label), 0, 0);

  hbox = gtk_hbox_new (FALSE, 5);
  gtk_box_pack_start (GTK_BOX (ret), hbox, FALSE, FALSE, 0);

  button = gtk_button_new_with_label ("iTunes/Winamp/Foobar/Apollo/QCD");
  g_signal_connect (G_OBJECT (button), "clicked",
    G_CALLBACK (text_file_info_button), "amip");
  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0); 
 
  button = gtk_button_new_with_label ("Windows Media Player");
  g_signal_connect (G_OBJECT (button), "clicked",
    G_CALLBACK (text_file_info_button), "wmp");
  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);  
  hbox = gtk_hbox_new (FALSE, 5);
  gtk_box_pack_start (GTK_BOX (ret), hbox, FALSE, FALSE, 0);
  
  /* *nix */
  label = gtk_label_new (_("*nix users: Play the current song in:"));
  gtk_box_pack_start (GTK_BOX (ret), label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label), 0, 0);

  hbox = gtk_hbox_new (FALSE, 5);
  gtk_box_pack_start (GTK_BOX (ret), hbox, FALSE, FALSE, 0);

  button = gtk_button_new_with_label ("XMMS");
  g_signal_connect (G_OBJECT (button), "clicked",
    G_CALLBACK (text_file_info_button), "xmms");
  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0); 
     
  /* OS X */
  label = gtk_label_new (_("OS X users: Play the current song in:"));
  gtk_box_pack_start (GTK_BOX (ret), label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label), 0, 0);

  hbox = gtk_hbox_new (FALSE, 5);
  gtk_box_pack_start (GTK_BOX (ret), hbox, FALSE, FALSE, 0);
 
  button = gtk_button_new_with_label ("iTunes");
  g_signal_connect (G_OBJECT (button), "clicked",
    G_CALLBACK (text_file_info_button), "itunes");
  gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0); 

  return ret;
}

void text_file_init () {
  gaim_prefs_add_string ("/plugins/gtk/autoprofile/components/text_file","");
  gaim_prefs_add_int ("/plugins/gtk/autoprofile/components/text_size", 
    1000);
}

struct component text =
{
  N_("Text File / Songs"),
  N_("Copies text from file- external programs (e.g. XMMS, Winamp, iTunes)\n"
     "can modify on regular basis"),
  'x',
  &text_file_generate,
  &text_file_init,
  NULL,
  NULL,
  &text_file_menu
};
